@@ -5,6 +5,7 @@ import numpy as np
 from .callback import Callback
 from torchelper.models.base_model import BaseModel
 from torchelper.utils.dist_util import master_only, get_bare_model
+from torchelper.utils import logger
 
 class ReduceLROnPlateau(Callback):
     """当指定指标没有提升时，自动下降学习率。
@@ -59,7 +60,7 @@ class ReduceLROnPlateau(Callback):
         """重置等待次数和冷却次数
         """
         if self.mode not in ['min', 'max']:
-            print('Learning rate reduction mode %s is unknown')
+            logger.error('Learning rate reduction mode %s is unknown')
             exit()
         if (self.mode == 'min'):
             self.monitor_op = lambda a, b: np.less(a, b - self.min_delta)
@@ -89,7 +90,7 @@ class ReduceLROnPlateau(Callback):
         metric:dict = model.get_metric_dict()
         current = metric.get(self.monitor, None)
         if current is None:
-            print('Learning rate reduction is conditioned on metric `%s` '
+            logger.error('Learning rate reduction is conditioned on metric `%s` '
                         'which is not available. Available metrics are: %s',
                         self.monitor, ','.join(list(metric.keys())))
 
@@ -106,13 +107,13 @@ class ReduceLROnPlateau(Callback):
                 if self.wait >= self.patience:
                     old_lr = self.get_lr(model)
                     if old_lr is None:
-                        print('can not get current learn rate !!!')
+                        logger.error('can not get current learn rate !!!')
                         exit()
                     if old_lr > np.float32(self.min_lr):
                         new_lr = old_lr * self.factor
                         new_lr = max(new_lr, self.min_lr)
                         self.set_lr(model, new_lr)
-                        print('\nEpoch %05d: ReduceLROnPlateau reducing learning '
+                        logger.warn('\nEpoch %05d: ReduceLROnPlateau reducing learning '
                                     'rate to %s.' % (epoch + 1, new_lr))
                         self.cooldown_counter = self.cooldown
                         self.wait = 0
